@@ -14,7 +14,7 @@ use Storable;
 use Test::BrewBuild;
 use Test::BrewBuild::Git;
 
-our $VERSION = '2.15';
+our $VERSION = '2.16';
 
 $| = 1;
 
@@ -33,7 +33,12 @@ sub new {
         $self->{debug} = $args{debug};
     }
 
-    $self->{auto} = defined $args{auto} ? $args{auto} : undef;
+    if (defined $args{auto}){
+        $self->{auto} = $args{auto};
+        $self->{auto} = 0 if $self->{auto} == 1;
+    }
+
+    $self->{autotest} = $args{autotest} if defined $args{autotest};
     $self->{forks} = defined $args{forks} ? $args{forks} : 4;
     $self->{rpi} = defined $args{rpi} ? $args{rpi} : undef;
 
@@ -60,7 +65,7 @@ sub auto {
 
     my $sleep = defined $self->{auto_sleep} ? $self->{auto_sleep} : 60;
 
-    my $runs = $params{auto};
+    my $runs = $self->{auto};
     my $run_count = 1;
 
     $log->_7("$runs auto runs planned") if $runs > 0;
@@ -100,50 +105,44 @@ sub auto {
 
         my $commit = $git->revision(remote => 1, repo => $params{repo});
         $commit = substr $commit, 0, 8;
-        
-        if (1){#}($ENV{BB_RUN_STATUS} ne $last_run_status){
-            $log->_7("current and last runs status are different. Running " .
-                     "plugins if available"
-            );
+    
+        if ($self->{rpi}){
+            $log->_7("RPi specific testing enabled");
 
-            if ($self->{rpi}){
-                $log->_7("RPi specific testing enabled");
+            if ($ENV{BB_RPI_LCD}){
+                my @pins = split /,/, $ENV{BB_RPI_LCD};
+                if (@pins == 6){
+                    if ($results_returned){
+                        my $time = strftime("%Y-%m-%d %H:%M:%S\n", localtime(time));
+                        
+                        $lcd = _lcd(@pins) if ! defined $lcd;
 
-                if ($ENV{BB_RPI_LCD}){
-                    my @pins = split /,/, $ENV{BB_RPI_LCD};
-                    if (@pins == 6){
-                        if ($results_returned){
-                            my $time = strftime("%Y-%m-%d %H:%M:%S\n", localtime(time));
-                            
-                            $lcd = _lcd(@pins) if ! defined $lcd;
+                        $lcd->position(0, 0);
+                        $lcd->print($time);
 
-                            $lcd->position(0, 0);
-                            $lcd->print($time);
+                        $lcd->position(0, 1);
+                        $lcd->print("$ENV{BB_RUN_STATUS}");
 
-                            $lcd->position(0, 1);
-                            $lcd->print("$ENV{BB_RUN_STATUS}");
-
-                            $lcd->position(8, 1);
-                            $lcd->print($commit);
-                        }
-                    }
-                    else {
-                        $log->_1(
-                            "in --rpi mode, but BB_RPI_LCD env var not set " .
-                            "correctly"
-                        );
-                        warn "bbdispatch is in --rpi mode, but the BB_RPI_LCD ".
-                             " env var isn't set. See the documentation...\n";
+                        $lcd->position(8, 1);
+                        $lcd->print($commit);
                     }
                 }
                 else {
-                    $log->_7("in --rpi mode, but BB_RPI_LCD env var not set");
+                    $log->_1(
+                        "in --rpi mode, but BB_RPI_LCD env var not set " .
+                        "correctly"
+                    );
+                    warn "bbdispatch is in --rpi mode, but the BB_RPI_LCD ".
+                         " env var isn't set. See the documentation...\n";
                 }
             }
             else {
-                $log->_7("not in --rpi mode");
+                $log->_7("in --rpi mode, but BB_RPI_LCD env var not set");
             }
         }
+        else {
+            $log->_7("not in --rpi mode");
+        }
 
         $log->_6(
             "auto run complete. Sleeping, then restarting if more runs required"
@@ -223,7 +222,7 @@ sub dispatch {
     %remotes = $self->_fork(\%remotes, $cmd, $repo);
 
     if (! -d 'bblog'){
-        mkdir 'bblog' or die $!;
+        mkdir 'bblog' or croak $!;
         $log->_7("created log dir: bblog");
     }
 
@@ -245,7 +244,7 @@ sub dispatch {
 
             my $content = $remotes{$ip}{build}{files}{$build_log};
             $log->_7("writing out log: " . getcwd() . "/bblog/$ip\_$build_log");
-            open my $wfh, '>', "bblog/$ip\_$build_log" or die $!;
+            open my $wfh, '>', "bblog/$ip\_$build_log" or croak $!;
             for (@$content){
                 print $wfh $_;
             }
@@ -305,13 +304,12 @@ sub _fork {
         }
     );
 
-    CLIENTS:
     for my $tester (keys %$remotes){
         $log->_7("spinning up tester: $tester");
 
         my $log = $log->child($tester);
 
-        $pm->start and next CLIENTS;
+        $pm->start and next;
 
         my %return;
 
@@ -321,7 +319,7 @@ sub _fork {
             Proto => 'tcp',
         );
         if (! $socket){
-            die "can't connect to remote $tester on port " .
+            croak "can't connect to remote $tester on port " .
                 "$remotes->{$tester}{port} $!\n";
         }
 
@@ -338,7 +336,7 @@ sub _fork {
 
         if ($ack ne $tester){
             $log->_0("comm error: syn \"$tester\" doesn't match ack \"$ack\"");
-            die "comm discrepancy: expected $tester, got $ack\n";
+            croak "comm discrepancy: expected $tester, got $ack\n";
         }
 
         if (! $cmd){
@@ -388,7 +386,8 @@ sub _fork {
 
             if (! $ok && ! defined $self->{auto}){
                 $log->_0("errors occurred... check your command line " .
-                         "string for invalid args. You sent in: $cmd"
+                         "string for invalid args. You sent in: $cmd.\n" .
+                         "The full error: $@"
                 );
                 exit;
             }
