@@ -13,7 +13,7 @@ use Storable;
 use Test::BrewBuild;
 use Test::BrewBuild::Git;
 
-our $VERSION = '2.15';
+our $VERSION = '2.16';
 
 $| = 1;
 
@@ -27,6 +27,7 @@ sub new {
     $self->{logfile} = $args{logfile};
 
     $self->{auto} = $args{auto};
+    $self->{csum} = $args{csum};
 
     $log = Logging::Simple->new(level => 0, name => 'Tester');
 
@@ -59,14 +60,14 @@ sub start {
 
     if ($self->status){
         my $fh;
-        open $fh, '<', $pid_file or die $!;
+        open $fh, '<', $pid_file or croak $!;
         my $existing_pid = <$fh>;
         close $fh;
 
         if ($existing_pid){
             if (kill(0, $existing_pid)){
                 $log->_0("tester is already running at PID $existing_pid");
-                die "\nTest::BrewBuild test server already running " .
+                croak "\nTest::BrewBuild test server already running " .
                     "on PID $existing_pid...\n\n";
             }
         }
@@ -107,6 +108,7 @@ sub start {
 
     if (defined $self->{auto}){
         push @args, ('--auto', $self->{auto});
+        push @args, ('--csum', $self->{csum}) if defined $self->{csum};
 
     }
     if (defined $self->{debug}){
@@ -116,8 +118,8 @@ sub start {
         push @args, ('--logfile');
     }
 
-    mkdir $work_dir or die "can't create $work_dir dir: $!" if ! -d $work_dir;
-    chdir $work_dir or die "can't change to dir $work_dir: $!";
+    mkdir $work_dir or croak "can't create $work_dir dir: $!" if ! -d $work_dir;
+    chdir $work_dir or croak "can't change to dir $work_dir: $!";
     $log->_7("chdir to: ".getcwd());
 
     my $bg;
@@ -139,7 +141,7 @@ sub start {
     print "\nStarted the Test::BrewBuild test server at PID $pid on IP " .
       "address $ip and TCP port $port...\n\n";
 
-    open my $wfh, '>', $pid_file or die $!;
+    open my $wfh, '>', $pid_file or croak $!;
     print $wfh $pid;
     close $wfh;
 
@@ -148,7 +150,7 @@ sub start {
     if ($self->status){
         sleep 1;
         my $fh;
-        open $fh, '<', $pid_file or die $!;
+        open $fh, '<', $pid_file or croak $!;
         my $existing_pid = <$fh>;
         close $fh;
 
@@ -157,7 +159,7 @@ sub start {
                 $log->_0("error! run bbtester --fg at the CLI and check for " .
                          "failure"
                 );
-                die "\nerror! run bbtester --fg at the command line and " .
+                croak "\nerror! run bbtester --fg at the command line and " .
                     "check for failure\n\n";
             }
         }
@@ -178,7 +180,7 @@ sub stop {
 
     my $pid_file = $self->_pid_file;
 
-    open my $fh, '<', $pid_file or die $!;
+    open my $fh, '<', $pid_file or croak $!;
     my $pid = <$fh>;
     close $fh;
     $log->_5("Stopping the BB test server at PID $pid");
@@ -211,7 +213,7 @@ sub listen {
         Listen => 5,
         Reuse => 1,
     );
-    die "cannot create socket $!\n" unless $sock;
+    croak "cannot create socket $!\n" unless $sock;
 
     $log->_6("successfully created network socket on IP $self->{ip} and port " .
              "$self->{port}"
@@ -285,7 +287,7 @@ sub listen {
             $log->_7("before all checks, repo set to $repo");
 
             if (-d $git->name($repo)){
-                chdir $git->name($repo) or die $!;
+                chdir $git->name($repo) or croak $!;
 
                 $log->_7("chdir to: ".getcwd());
 
@@ -293,39 +295,43 @@ sub listen {
                 $log->_7("using Git: " . $git->git);
 
                 if (defined $self->{auto} && $self->{auto}){
-                    $log->_6("in auto mode, checking commit checksum reqs");
+                    $log->_6("in auto mode");
 
-                    my $status = $git->status(repo => $git->link);
-                    my $local_sum = $git->revision(repo => $git->link);
-                    my $remote_sum = $git->revision(
-                        remote => 1,
-                        repo => $git->link
-                    );
+                    if (! defined $self->{csum}){
+                        $log->_6("in auto mode, checking commit checksum reqs");
 
-                    $log->_7(
-                        "\nGit check:" .
-                        "\n\tstatus: $status" .
-                        "\n\tlocal: $local_sum" .
-                        "\n\tremote: $remote_sum"
-                    );
-
-                    if (! $status) {
-                        $log->_6(
-                            "local repo is ahead in commits than remote... ".
-                            "Nothing to do"
+                        my $status = $git->status(repo => $git->link);
+                        my $local_sum = $git->revision(repo => $git->link);
+                        my $remote_sum = $git->revision(
+                            remote => 1,
+                            repo => $git->link
                         );
-                        $self->{log} = '';
-                        shutdown($dispatch, 1);
-                        next;
-                    }
 
-                    if ($local_sum eq $remote_sum) {
-                        $log->_6(
-                            "local and remote commit sums match. Nothing to do"
+                        $log->_7(
+                            "\nGit check:" .
+                            "\n\tstatus: $status" .
+                            "\n\tlocal: $local_sum" .
+                            "\n\tremote: $remote_sum"
                         );
-                        $self->{log} = '';
-                        shutdown($dispatch, 1);
-                        next;
+
+                        if (! $status) {
+                            $log->_6(
+                                "local repo is ahead in commits than remote... ".
+                                "Nothing to do"
+                            );
+                            $self->{log} = '';
+                            shutdown($dispatch, 1);
+                            next;
+                        }
+
+                        if ($local_sum eq $remote_sum) {
+                            $log->_6(
+                                "local and remote commit sums match. Nothing to do"
+                            );
+                            $self->{log} = '';
+                            shutdown($dispatch, 1);
+                            next;
+                        }
                     }
                 }
 
@@ -399,7 +405,7 @@ sub listen {
                 for (@entries){
                     $log->_7("processing log file: " .getcwd() ."/$_");
                     next if ! -f || ! /\.bblog/;
-                    open my $fh, '<', $_ or die $!;
+                    open my $fh, '<', $_ or croak $!;
                     @{ $res->{files}{$_} } = <$fh>;
                     close $fh;
                 }
@@ -407,7 +413,7 @@ sub listen {
                 $log->_7("chdir to: ".getcwd());
 
                 $log->_7("removing log dir: " . getcwd() . "/bblog");
-                remove_tree 'bblog' or die $!;
+                remove_tree 'bblog' or croak $!;
             }
             $log->_5("storing and sending results back to dispatcher");
             $res->{log} = $self->{log};
